%% DESCRIPTION
% Declaration of plant parameters
%
% Files required: none

% Author: Sean Costello
% Automatic Control Lab, EPFL, Lausanne, Switzerland
% email: sean.costello@epfl.ch
% Website: http://people.epfl.ch/sean.costello
% March 2014; Last revision: 25-April-2014

%% ------------- CODE --------------
% plant parameters

P.r = 250;
P.m = 300; 
P.g = 9.8;
P.rho = 1.2;

P.d = 10; 
P.A = 25;
P.z_min = 25; 

%% wind parameters
P.w_ref = 8; 
P.z_ref = 10; 
P.a = .15; 
P.chi = deg2rad(15); 
P.T_w = .5; % sampling frequency of random noise generator (s)
P.var_w = 1.2; % wind-speed noise variance (m/s)
P.meanw_n = -P.var_w/(2*P.w_ref);
P.L_w = 100; % turbulence length scale (m)

% derive the wind model parameters (do not change!)         
P.k_sv = sqrt(P.var_w)/P.w_ref; % called k_{\sigma,v} in documentation
T_F = P.L_w/P.w_ref; 
V_F = sqrt((2*pi*T_F)/(P.T_w*beta(0.5,1/3))); % amplification factor, called K_F by intechopen
s = tf('s');
H_F = V_F/(1+s*T_F); 
P.num_H_F = H_F.num{1};
P.den_H_F = H_F.den{1};

%%

P.T_s = .125; 

P.var_theta= 1e-4; 
P.var_phi = 1e-4;
P.var_psi = .02;   

% steering actuator dynamics
P.u_max = 7.5; %6.5; 
tau_u = .2; 
P.motornum = 1; % first-order dynamic
P.motorden = [tau_u 1]; 

% wing lift- and drag- curve parameters
P.CD0 = .11;
P.CD2 = 1.168;
P.CL0 = .57;
P.CL1 = 1.547; 

% initial conditions
P.theta_0 = .11;
P.dtheta_0 = .15;
P.phi_0 = 0;
P.dphi_0 = 0;

if(1) %plots of the L/D curve and the wind shear
    %% L/D curve
    alpha_valsD = 0:1:30;
    alpha_vals = deg2rad(alpha_valsD);
    CD_vals = P.CD0 + P.CD2*alpha_vals.^2;
    CL_vals = P.CL0 + P.CL1*alpha_vals;
    figure('name','L and D curves for plant')
    plot(alpha_valsD, [CL_vals; CD_vals])
    ylabel('(-)')
    xlabel('angle of attack, \alpha (degrees)')
    legend('C_L','C_D')
    figure('name','L/D curve for plant')
    plot(alpha_valsD, CL_vals./CD_vals)
    ylabel('C_L/C_D (-)')
    xlabel('angle of attack, \alpha (degrees)')

    %% power law for windspeed as a function of height
    % from Cristina Archer, Airborne Wind Energy book 2014
    z_vals = 1:P.r;
    for i = 1:length(z_vals)
        w(i) = P.w_ref*(z_vals(i)/P.z_ref)^P.a;
    end
    figure('Name', 'altitude vs. wind strength'),
    plot(w, z_vals), xlabel('w (m/s)'), ylabel('z (m)')
end
